==> ssp-center-api-0.1.35-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/MeidaActivitySlotStatisticsDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:MeidaActivitySlotStatisticsDto <br/>
 * Function: 媒体活动广告统计. <br/>
 * Date: 2016年12月19日 下午1:54:35 <br/>
 * 
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
public class MeidaActivitySlotStatisticsDto extends BaseStatisticsDataDto implements Serializable {

    /** 序列号 */
    private static final long serialVersionUID = 7964975683391052338L;

    /** 媒体用户ID */
    private Long              mediaId;
    /** 媒体ID */
    private Long              appId;
    /** 媒体名称 */
    private String            appName;
    /** 负责人id */
    private List<Long>        managerList;
    /** 负责人姓名 */
    private  List<String>     managerNameList;
    /** 所属平台 */
    private String            platform;
    /** 活动ID */
    private Long              activityId;
    /** 活动类型 */
    private String            activityType;
    /** 活动名 */
    private String            activityTitle;
    /** 广告位ID */
    private Long              slotId;
    /** 广告位名称 */
    private String            slotName;
    /** 广告位类型 */
    private Integer           slotType;
    /** 广告位规格ID */
    private Long              slotMsId;

    /**
     * mediaId.
     *
     * @return the mediaId
     * @since JDK 1.6
     */
    public Long getMediaId() {
        return mediaId;
    }

    /**
     * mediaId.
     *
     * @param mediaId the mediaId to set
     * @since JDK 1.6
     */
    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getManagerList() {
        return managerList;
    }

    public void setManagerList(List<Long> managerList) {
        this.managerList = managerList;
    }

    public List<String> getManagerNameList() {
        return managerNameList;
    }

    public void setManagerNameList(List<String> managerNameList) {
        this.managerNameList = managerNameList;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * activityId.
     *
     * @return the activityId
     * @since JDK 1.6
     */
    public Long getActivityId() {
        return activityId;
    }

    /**
     * activityId.
     *
     * @param activityId the activityId to set
     * @since JDK 1.6
     */
    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    /**
     * activityType.
     *
     * @return the activityType
     * @since JDK 1.6
     */
    public String getActivityType() {
        return activityType;
    }

    /**
     * activityType.
     *
     * @param activityType the activityType to set
     * @since JDK 1.6
     */
    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    /**
     * activityTitle.
     *
     * @return the activityTitle
     * @since JDK 1.6
     */
    public String getActivityTitle() {
        return activityTitle;
    }

    /**
     * activityTitle.
     *
     * @param activityTitle the activityTitle to set
     * @since JDK 1.6
     */
    public void setActivityTitle(String activityTitle) {
        this.activityTitle = activityTitle;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * slotType.
     *
     * @return the slotType
     * @since JDK 1.6
     */
    public Integer getSlotType() {
        return slotType;
    }

    /**
     * slotType.
     *
     * @param slotType the slotType to set
     * @since JDK 1.6
     */
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }
    
    /**
     * slotMsId.
     *
     * @return the slotMsId
     * @since JDK 1.6
     */
    public Long getSlotMsId() {
        return slotMsId;
    }

    /**
     * slotMsId.
     *
     * @param slotMsId the slotMsId to set
     * @since JDK 1.6
     */
    public void setSlotMsId(Long slotMsId) {
        this.slotMsId = slotMsId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }
}

==> ssp-center-api-0.8.29-20201023.062803-19-sources.jar: cn/com/duiba/tuia/ssp/center/api/dto/MeidaActivitySlotStatisticsDto.java <==
package cn.com.duiba.tuia.ssp.center.api.dto;

import java.io.Serializable;
import java.util.List;

import org.apache.commons.lang.builder.ToStringBuilder;

/**
 * ClassName:MeidaActivitySlotStatisticsDto <br/>
 * Function: 媒体活动广告统计. <br/>
 * Date: 2016年12月19日 下午1:54:35 <br/>
 * 
 * @author guyan
 * @version
 * @since JDK 1.6
 * @see
 */
public class MeidaActivitySlotStatisticsDto extends BaseStatisticsDataDto implements Serializable {

    /** 序列号 */
    private static final long serialVersionUID = 7964975683391052338L;

    /** 媒体用户ID */
    private Long              mediaId;
    /** 媒体ID */
    private Long              appId;
    /** 媒体名称 */
    private String            appName;
    /** 负责人id */
    private List<Long>        managerList;
    /** 负责人姓名 */
    private  List<String>     managerNameList;
    /** 所属平台 */
    private String            platform;
    /** 活动ID */
    private Long              activityId;
    /** 活动类型 */
    private String            activityType;
    /** 活动名 */
    private String            activityTitle;
    /** 广告位ID */
    private Long              slotId;
    /** 广告位名称 */
    private String            slotName;
    /** 广告位类型 */
    private Integer           slotType;
    /** 广告位规格ID */
    private Long              slotMsId;

    /** */
    private Long              subMediaId;

    /**
     * 从 startDate到endDate之间有数据的天数
     */
    private Integer days;

    /**
     * 媒体自定义模块信息
     */
    private String mediaUnit;

    /**
     * 客户类型 0-- 未选择  1--人工服务   2--自主化标识客户
     */
    private Integer clientType;

    /**
     * 预估得分
     */
    private String estimateScore;

    /**
     * 质量等级
     */
    private String estimateLevel;

    public Integer getClientType() {
        return clientType;
    }

    public void setClientType(Integer clientType) {
        this.clientType = clientType;
    }

    /**
     * mediaId.
     *
     * @return the mediaId
     * @since JDK 1.6
     */
    public Long getMediaId() {
        return mediaId;
    }

    /**
     * mediaId.
     *
     * @param mediaId the mediaId to set
     * @since JDK 1.6
     */
    public void setMediaId(Long mediaId) {
        this.mediaId = mediaId;
    }

    /**
     * appId.
     *
     * @return the appId
     * @since JDK 1.6
     */
    public Long getAppId() {
        return appId;
    }

    /**
     * appId.
     *
     * @param appId the appId to set
     * @since JDK 1.6
     */
    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public List<Long> getManagerList() {
        return managerList;
    }

    public void setManagerList(List<Long> managerList) {
        this.managerList = managerList;
    }

    public List<String> getManagerNameList() {
        return managerNameList;
    }

    public void setManagerNameList(List<String> managerNameList) {
        this.managerNameList = managerNameList;
    }

    /**
     * appName.
     *
     * @return the appName
     * @since JDK 1.6
     */
    public String getAppName() {
        return appName;
    }

    /**
     * appName.
     *
     * @param appName the appName to set
     * @since JDK 1.6
     */
    public void setAppName(String appName) {
        this.appName = appName;
    }

    /**
     * platform.
     *
     * @return the platform
     * @since JDK 1.6
     */
    public String getPlatform() {
        return platform;
    }

    /**
     * platform.
     *
     * @param platform the platform to set
     * @since JDK 1.6
     */
    public void setPlatform(String platform) {
        this.platform = platform;
    }

    /**
     * activityId.
     *
     * @return the activityId
     * @since JDK 1.6
     */
    public Long getActivityId() {
        return activityId;
    }

    /**
     * activityId.
     *
     * @param activityId the activityId to set
     * @since JDK 1.6
     */
    public void setActivityId(Long activityId) {
        this.activityId = activityId;
    }

    /**
     * activityType.
     *
     * @return the activityType
     * @since JDK 1.6
     */
    public String getActivityType() {
        return activityType;
    }

    /**
     * activityType.
     *
     * @param activityType the activityType to set
     * @since JDK 1.6
     */
    public void setActivityType(String activityType) {
        this.activityType = activityType;
    }

    /**
     * activityTitle.
     *
     * @return the activityTitle
     * @since JDK 1.6
     */
    public String getActivityTitle() {
        return activityTitle;
    }

    /**
     * activityTitle.
     *
     * @param activityTitle the activityTitle to set
     * @since JDK 1.6
     */
    public void setActivityTitle(String activityTitle) {
        this.activityTitle = activityTitle;
    }

    /**
     * slotId.
     *
     * @return the slotId
     * @since JDK 1.6
     */
    public Long getSlotId() {
        return slotId;
    }

    /**
     * slotId.
     *
     * @param slotId the slotId to set
     * @since JDK 1.6
     */
    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    /**
     * slotName.
     *
     * @return the slotName
     * @since JDK 1.6
     */
    public String getSlotName() {
        return slotName;
    }

    /**
     * slotName.
     *
     * @param slotName the slotName to set
     * @since JDK 1.6
     */
    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    /**
     * slotType.
     *
     * @return the slotType
     * @since JDK 1.6
     */
    public Integer getSlotType() {
        return slotType;
    }

    /**
     * slotType.
     *
     * @param slotType the slotType to set
     * @since JDK 1.6
     */
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }
    
    /**
     * slotMsId.
     *
     * @return the slotMsId
     * @since JDK 1.6
     */
    public Long getSlotMsId() {
        return slotMsId;
    }

    /**
     * slotMsId.
     *
     * @param slotMsId the slotMsId to set
     * @since JDK 1.6
     */
    public void setSlotMsId(Long slotMsId) {
        this.slotMsId = slotMsId;
    }

    public Long getSubMediaId() {
        return subMediaId;
    }

    public void setSubMediaId(Long subMediaId) {
        this.subMediaId = subMediaId;
    }

    @Override
    public String toString() {
        return ToStringBuilder.reflectionToString(this);
    }

    public Integer getDays() {
        return days;
    }

    public void setDays(Integer days) {
        this.days = days;
    }

    public String getMediaUnit() {
        return mediaUnit;
    }

    public void setMediaUnit(String mediaUnit) {
        this.mediaUnit = mediaUnit;
    }

    public String getEstimateScore() {
        return estimateScore;
    }

    public void setEstimateScore(String estimateScore) {
        this.estimateScore = estimateScore;
    }

    public String getEstimateLevel() {
        return estimateLevel;
    }

    public void setEstimateLevel(String estimateLevel) {
        this.estimateLevel = estimateLevel;
    }

}
